#[unsafe(no_mangle)]pub unsafe extern "C" fn nemo_flow_initialize_plugins(
config_json: *const c_char,
out_json: *mut *mut c_char,
) -> NemoFlowStatusExpand description
Initialize the active global plugin components and return the resulting diagnostics report.
Safety
config_json must be a valid C string and out_json must be a valid, non-null pointer.